@@ -1,15 +1,15 @@
 #--------------------------------------------------------------------
 #   svarmod.sb.R (npsp package)
 #--------------------------------------------------------------------
-#   kappasb(x, dk = 0)
-#   disc.sb(nx, dk = 0, rmax = 1)
-#   fitsvar.sb.iso(esv, dk = ncol(esv$data$x), ...)
+#   kappasb(x, dk)
+#   disc.sb(nx, dk, rmax)
+#   fitsvar.sb.iso(esv, dk, nx, rmax, min.contrib, method, iter, tol)
 #
+#   (c) R. Fernandez-Casal         Last revision: Apr 2013
+#--------------------------------------------------------------------
 # PENDENTE:
 #   - documentacin
 #   - @examples
-#
-#   (c) R. Fernandez-Casal         Last revision: Apr 2013
 #--------------------------------------------------------------------
 
 
@@ -53,7 +53,7 @@ kappasb <- function(x, dk = 0) {
       # Alternativamente se podra hacer pmax(x, .Machine$double.eps^0.5)
   }    
   res <- switch( min(dk + 1, 5),
-      exp(-x^2),            # dk = 0
+      exp(-x*x),            # dk = 0
       cos(x),               # dk = 1
       besselJ(x, nu = 0),   # dk = 2
       sin(x)/x,             # dk = 3
@@ -82,7 +82,7 @@ kappasb <- function(x, dk = 0) {
 #' @param  rmax  maximum lag considered.
 #' @details
 #' If \code{dk >= 1}, the nodes are computed as: 
-#' \deqn{x_i = q_i/rmax; i = 1,\ldots, n,} where 
+#' \deqn{x_i = q_i/rmax; i = 1,\ldots, nx,} where 
 #' \eqn{q_i} are the first \eqn{n} roots of \eqn{J_{(d-2)/2}}, \eqn{J_p} 
 #' is the Bessel function of order \eqn{p} and \eqn{rmax} 
 #' is the maximum lag considered. The computation of the zeros of the Bessel  
@@ -91,7 +91,8 @@ kappasb <- function(x, dk = 0) {
 #' If \code{dk == 0} (corresponding to a model valid in any spatial dimension), 
 #' the nodes are computed so the gaussian variogram models involved have
 #' practical ranges: 
-#'    \deqn{r_i = ( 1 + 1.2(i-1))rmax/n; i = 1,\ldots, n.}
+#    \deqn{r_i = ( 1 + 1.2(i-1))rmax/nx; i = 1,\ldots, nx.}
+#'    \deqn{r_i = ( 1 + (i-1))rmax/nx; i = 1,\ldots, nx.}
 #' @references
 #' Ball, J.S. (2000) Automatic computation of zeros of Bessel functions and other
 #'   special functions. \emph{SIAM Journal on Scientific Computing}, \bold{21}, 
@@ -117,7 +118,8 @@ disc.sb <- function(nx, dk = 0, rmax = 1) {
         # OJO: equiv. modelos gausianos, pueden aparecer inestabilidades
         # Nodos de discretizacin "geomtricos"
         # return( 1.732/(seq(1, by = -1/nx, length = nx) * rmax) )
-        return( sqrt(3)/(seq(1/nx, by = 1.2/nx, length = nx) * rmax) )
+        # return( sqrt(3)/(seq(1/nx, by = 1.2/nx, length = nx) * rmax) )
+        return( sqrt(3)/(seq(1/nx, 1, length = nx) * rmax) )
     # Let's go FORTRAN!
     #   subroutine disc_sbv(nx, x, dim, range)
     ret <-.Fortran( "disc_sbv", nx = as.integer(nx), x = double(nx), 
@@ -129,7 +131,7 @@ disc.sb <- function(nx, dk = 0, rmax = 1) {
 
 #--------------------------------------------------------------------
 #   fitsvar.sb.iso(esv, dk = ncol(esv$data$x), nx = NULL, rmax = esv$grid$max, 
-#        min.contrib = 15, method = c("cressie", "equal", "npairs", "gstat"), 
+#        min.contrib = 10, method = c("cressie", "equal", "npairs", "linear"), 
 #        iter = 10, tol = sqrt(.Machine$double.eps)) {
 #--------------------------------------------------------------------
 #' Fit an isotropic Shapiro-Botha variogram model
@@ -140,15 +142,16 @@ disc.sb <- function(nx, dk = 0, rmax = 1) {
 #' roots of Bessel functions (see \code{\link{disc.sb}}).
 #' @param  esv pilot semivariogram estimate, a \code{\link{np.svar}}-\code{\link{class}} 
 #'   (or \code{\link{svar.bin}}) object. Typically an output of the function
-#'   \code{\link{svarisonp}}. 
-#' @param  dk  dimension of the kappa function (should be greater than or equal 
-#'   to the dimension of the spatial process \code{ncol(esv$data$x)}).
+#'   \code{\link{np.svariso}}. 
+#' @param  dk  dimension of the kappa function (\code{dk == 0} corresponds to a model 
+#'   valid in any dimension; if \code{dk > 0}, it should be greater than 
+#'   or equal to the dimension of the spatial process \code{ncol(esv$data$x)}).
 #' @param  nx  number of discretization nodes. Defaults to \code{min(nesv - 1, 50)},
 #' where \code{nesv} is the number of semivariogram estimates.
 #' @param  rmax  maximum lag considered in the discretization
 #'   (range of the fitted variogram on output).
-#' @param  min.contrib  minimum number of contributing pairs 
-#' (pilot estimates with a lower number are ignored).
+#' @param  min.contrib  minimum number of (equivalent) contributing pairs 
+#' (pilot estimates with a lower number are ignored, with a warning).
 #' @param  method  string indicating the WLS fitting method to be used
 #'   (e.g. \code{method = "cressie"}). See "Details" below.
 #' @param  iter  maximum number of interations of the WLS algorithm (used only  
@@ -161,23 +164,24 @@ disc.sb <- function(nx, dk = 0, rmax = 1) {
 #' The different options for the argument \code{method} define the WLS algorithm used:
 #' \describe{
 #'  \item{\code{"cressie"}}{The default method. The procedure is
-#'  iterative, with \eqn{w_i=1} (OLS) used for the first step
+#'  iterative, with \eqn{w_i = 1} (OLS) used for the first step
 #'  and with the weights recalculated at each iteration,
 #'  following Cressie (1985), until convergence: \deqn{w_i =
 #'  N(h_i)/\gamma(\hat{\theta}; h_i)^2,} where \eqn{N(h_i)}
 #'  is the (equivalent) number of contributing pairs in the
 #'  estimation at lag \eqn{h_i}.}
-#'  \item{\code{"equal"}}{Ordinary least squares: \eqn{w_i=1}.}
-#'  \item{\code{"npairs"}}{\eqn{w_i=N(h_i).}} 
-#'  \item{\code{"gstat"}}{The default fitting method in \pkg{gstat}:
-#'  \eqn{w_i = N(h_i)/h_i^2}.} 
+#'  \item{\code{"equal"}}{Ordinary least squares: \eqn{w_i = 1}.}
+#'  \item{\code{"npairs"}}{\eqn{w_i = N(h_i).}} 
+#'  \item{\code{"linear"}}{\eqn{w_i = N(h_i)/h_i^2} 
+#'  (default fitting method in \pkg{gstat} package).} 
 #' } 
 #' Function \code{\link[quadprog]{solve.QP}} of \pkg{quadprog} package is used 
 #' to solve the quadratic programming problem. If \code{nx} and/or \code{dim(esv)}
 #' are large, this function may fail with error message "matrix D in quadratic 
 #' function is not positive definite!". 
 #' @return
-#' Returns the fitted variogram model, an object of \code{\link{class}} \code{sb.iso} (extends \code{\link{svarmod}})
+#' Returns the fitted variogram model, an object of \code{\link{class}} \code{fitsvar} 
+# (extending \code{\link{sb.iso}}: a \code{\link{svarmod}}) object
 #' with an additional component \code{fit} containing:
 #' \item{u}{vector of lags/distances.}
 #' \item{sv}{vector of pilot semivariogram estimates.}
@@ -207,11 +211,11 @@ disc.sb <- function(nx, dk = 0, rmax = 1) {
 #'   conditionally non-negative definite functions. \emph{Computational Statistics 
 #'   and Data Analysis}, \bold{11}, 87-96. 
 #' @seealso
-#' \code{\link{svarmod.sb.iso}}, \code{\link{disc.sb}}.
+#' \code{\link{svarmod.sb.iso}}, \code{\link{disc.sb}}, \code{\link{plot.fitsvar}}.
 #' @export
 #--------------------------------------------------------------------
 fitsvar.sb.iso <- function(esv, dk = ncol(esv$data$x), nx = NULL, rmax = esv$grid$max, 
-        min.contrib = 15, method = c("cressie", "equal", "npairs", "gstat"), 
+        min.contrib = 10, method = c("cressie", "equal", "npairs", "linear"), 
         iter = 10, tol = sqrt(.Machine$double.eps)) {
 #   PENDENTE:
 #     - Rounding errors?  w <- w/sum(w)
@@ -231,22 +235,23 @@ fitsvar.sb.iso <- function(esv, dk = ncol(esv$data$x), nx = NULL, rmax = esv$gri
     # Let's go...
     u <- as.numeric(coords(esv))
     if (inherits(esv, "np.svar")) { 
-        # class "np.svar"
+        # "np.svar" class 
         v <- esv$est
         if (!is.null(esv$locpol$hat)) {
             # Aproximacin varianza estilo Cressie (suponiendo independencia) para ajuste wls
-            # PENDIENTE: ESCRIBIR/REVISAR ESTAS CUENTAS
-            n <- with(esv, rowSums(locpol$hat^2 / matrix(binw, nrow=grid$n, ncol=grid$n, byrow=TRUE)))
-            n <- 1 / n    # n equivalente de aportaciones
+            # PENDIENTE: ESCRIBIR/REVISAR ESTAS CUENTAS            
+            n <- 1 / with(esv, rowSums(locpol$hat^2 / 
+                pmax(matrix(binw, nrow=grid$n, ncol=grid$n, byrow=TRUE), 1))) # n equivalente de aportaciones
         } else {
             n <- esv$binw # n de aportaciones            
         }    
     } else {
-        # class "svar.bin"
+        # "svar.bin" class 
         v <- esv$biny
         n <- esv$binw # n de aportaciones    
     }
     if (!all(index <- n >= min.contrib)) {
+        warning("some pilot semivariogram estimates will be ignored (contrib < min.contrib)")
         u <- u[index]
         v <- v[index]
         n <- n[index]
@@ -268,7 +273,7 @@ fitsvar.sb.iso <- function(esv, dk = ncol(esv$data$x), nx = NULL, rmax = esv$gri
     # Reescalar pesos
     w <- switch(method,
         npairs =  n,
-        gstat =   n/pmax(u^2, .Machine$double.eps^0.5),
+        linear =   n/pmax(u^2, .Machine$double.eps^0.5),
                   1 # default: "cressie", "equal"
         )
     w <- w/sum(w)
@@ -306,8 +311,12 @@ fitsvar.sb.iso <- function(esv, dk = ncol(esv$data$x), nx = NULL, rmax = esv$gri
     result <- svarmod.sb.iso( dk = dk, x = x, z = sol[-n.par], nu = sol[n.par], 
           range = rmax)
     result$fit <- list(u = u, sv = v, fitted.sv = fit, wls = wls, 
-        method = method, iter = iter)       
+        method = method, iter = iter)  
+    oldClass(result) <- c("fitsvar", oldClass(result))     
     return(result)
-}
+#--------------------------------------------------------------------
+} # fitsvar.sb.iso
+
+
 
 
