@@ -1,3 +1,12 @@
+#--------------------------------------------------------------------
+#   zzz.R (npsp package)
+#--------------------------------------------------------------------
+#   .onAttach(libname, pkgname)
+#
+#   (c) R. Fernandez-Casal         Last revision: Apr 2013
+#--------------------------------------------------------------------
+
+
 #--------------------------------------------------------------------
 .onAttach <- function(libname, pkgname){
 #--------------------------------------------------------------------
@@ -5,8 +14,8 @@
     pkg.info <- drop( read.dcf( file = system.file("DESCRIPTION", package = "npsp"),
                       fields = c("Title", "Version", "Date") ))
     packageStartupMessage( 
-      paste("\n Package npsp:", pkg.info["Title"], "\n"),
+      paste(" Package npsp:", pkg.info["Title"], "\n"),
       paste(" version ", pkg.info["Version"], " (built on ", pkg.info["Date"], ").\n", sep=""),
-      " Copyright R. Fernandez-Casal 2012, 2013.\n",      
+      " Copyright R. Fernandez-Casal 2012-2014.\n",      
       " Type demo(package = 'npsp') to obtain the list of available demos.\n")
 }
